Struct Json
pub struct Json<T>(pub T)
where
T: ?Sized;Expand description
Json for json and jsonb fields
Will attempt to cast to type passed in as the generic.
[dependencies]
serde_json = { version = "1.0", features = ["raw_value"] }
Example
#[derive(Deserialize)]
struct Book {
name: String
}
#[derive(sqlx::FromRow)]
struct Author {
name: String,
books: sqlx::types::Json<Book>
}Can also be used to turn the json/jsonb into a hashmap
use std::collections::HashMap;
use serde::Deserialize;
#[derive(Deserialize)]
struct Book {
name: String
}
#[derive(sqlx::FromRow)]
struct Library {
id: String,
dewey_decimal: sqlx::types::Json<HashMap<String, Book>>
}If the query macros are used, it is necessary to tell the macro to use
the Json adapter by using the type override syntax
#[derive(sqlx::FromRow)]
struct Book {
title: String,
}
#[derive(sqlx::FromRow)]
struct Author {
name: String,
books: sqlx::types::Json<Book>,
}
// Note the type override in the query string
let authors = sqlx::query_as!(
Author,
r#"
SELECT name, books as "books: Json<Book>"
FROM authors
"#
)
.fetch_all(&mut conn)
.await?;Tuple Fields
0: TTrait Implementations
impl<'r, T> Decode<'r, Postgres> for Json<T>where
T: 'r + Deserialize<'r>,
impl<'r, T> Decode<'r, Postgres> for Json<T>where
T: 'r + Deserialize<'r>,
impl<'de, T> Deserialize<'de> for Json<T>where
T: Deserialize<'de> + ?Sized,
impl<'de, T> Deserialize<'de> for Json<T>where
T: Deserialize<'de> + ?Sized,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Json<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Json<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl<'q, T> Encode<'q, Postgres> for Json<T>where
T: Serialize,
impl<'q, T> Encode<'q, Postgres> for Json<T>where
T: Serialize,
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
impl<T> Ord for Json<T>
impl<T> Ord for Json<T>
impl<T> PartialOrd for Json<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for Json<T>where
T: PartialOrd + ?Sized,
impl<T> PgHasArrayType for Json<T>
impl<T> PgHasArrayType for Json<T>
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl<T> Serialize for Json<T>
impl<T> Serialize for Json<T>
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl<T> Type<Postgres> for Json<T>
impl<T> Type<Postgres> for Json<T>
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
fn compatible(ty: &PgTypeInfo) -> bool
fn compatible(ty: &PgTypeInfo) -> bool
impl<T> Copy for Json<T>
impl<T> Eq for Json<T>
impl<T> StructuralPartialEq for Json<T>where
T: ?Sized,